module.exports = defineTest({
	description: 'exports variables at end, if possible',
	options: { output: { name: 'myBundle' } }
});
